import 'package:flutter/cupertino.dart';
import 'package:flutter/services.dart';

enum BannerEvent {
  onLoadAd,
  onFailedAd,
  onClickAd
}

typedef void FlutterBannerListener(BannerEvent event);

class FlutterBaseBanner {
  static const _DEFAULT_CHANNELNAME = "com.bidmad.sdk.banner/Flutter";
  String _channelNm;
  MethodChannel _platform;
  FlutterBannerListener _listener;

  Map<String, BannerEvent> bannerEventMap = <String, BannerEvent>{
    'onLoadAd': BannerEvent.onLoadAd,
    'onFailedAd': BannerEvent.onFailedAd,
    'onClickAd': BannerEvent.onClickAd
  };

  String get channelNm => _channelNm;

  FlutterBaseBanner({
    @required FlutterBannerListener listener,
    String channelName
  }){
    this._listener = listener;
    this._channelNm = channelName ?? _DEFAULT_CHANNELNAME;
    _initChannel(_channelNm);
  }

  Future<void> _initChannel(String channelNm) async {
    _platform = MethodChannel(channelNm);
    _platform.setMethodCallHandler(_handleMethod);
  }

  Future<void> load(int y) async {
    await _platform.invokeMethod('load', {"y":y});
  }

  Future<void> setInterval(int sec) async {
    await _platform.invokeMethod('setInterval', {"sec":sec});
  }

  Future<void> setHouseImage(bool useHouseImage) async {
    await _platform.invokeMethod('setHouseImage', {"useHouseImage":useHouseImage});
  }

  Future<void> setAdInfo(String zoneId) async {
    await _platform.invokeMethod('setAdInfo', zoneId);
  }

  Future<void> removeAdView() async {
    await _platform.invokeMethod('removeAdView');
  }

  Future<dynamic> _handleMethod(MethodCall call) async {

    switch (call.method) {
      case 'onLoadAd':
      case 'onFailedAd':
      case 'onClickAd':
        final BannerEvent bannerAdEvent = bannerEventMap[call.method];
        _listener(bannerAdEvent);
        break;
      default:
        throw ('method not defined');
    }
  }
}